netapp_ontap.models.volume_constituents_space_snapshot API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.volume_constituents_space_snapshot`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class VolumeConstituentsSpaceSnapshotSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the VolumeConstituentsSpaceSnapshot object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `autodelete_enabled: bool PATCH`

    Specifies whether snapshot autodelete is currently enabled on this volume.

  `reserve_percent: Size GET POST PATCH`

    The space that has been set aside as a reserve for snapshot usage, in percent.

  `used: Size GET`

    The total space used by snapshots in the volume, in bytes.